==> audio_player_chopinzinhofm-0.0.2.tar.gz: android/src/main/java/audioplayerchopinzinhofm/lucas/com/audio_player_chopinzinhofm/AudioService.java <==
package audioplayerchopinzinhofm.lucas.com.audio_player_chopinzinhofm;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.media.Rating;
import android.media.session.MediaController;
import android.media.session.MediaSession;
import android.media.session.MediaSessionManager;
import android.os.Build;
import android.os.IBinder;
import android.os.PowerManager;
import android.support.annotation.Nullable;
import android.support.annotation.RequiresApi;
import android.util.Log;

import java.io.IOException;

public class AudioService extends Service implements MediaPlayer.OnPreparedListener, MediaPlayer.OnErrorListener {

    public static final String CHANNEL_ID = "ForegroundServiceChannel";
    public static final String ACTION_PLAY = "action_play";
    public static final String ACTION_PAUSE = "action_pause";
    public static final String ACTION_STOP = "action_stop";
    private static final String URL = "http://9.fm5.com.br:8804/;";


    private MediaPlayer mMediaPlayer;

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        createNotificationChannel();

        if (intent.getAction().equals(ACTION_PLAY)) {
            if (mMediaPlayer == null) {
                startMediaPlayer();
            } else {
                play(mMediaPlayer);
            }
        } else if (intent.getAction().equals(ACTION_PAUSE)) {
            pause(mMediaPlayer);
        } else if (intent.getAction().equals(ACTION_STOP)) {
            stop();
        }

        return START_NOT_STICKY;
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void startMediaPlayer() {
        mMediaPlayer = new MediaPlayer();
        mMediaPlayer.setAudioStreamType(AudioManager.STREAM_MUSIC);
        mMediaPlayer.setWakeMode(getApplicationContext(), PowerManager.PARTIAL_WAKE_LOCK);
        try {
            mMediaPlayer.setDataSource(URL);
        } catch (IOException e) {
            e.printStackTrace();
        }
        mMediaPlayer.setOnPreparedListener(this);
        mMediaPlayer.setOnErrorListener(this);
        mMediaPlayer.prepareAsync();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void pause(MediaPlayer player) {
        player.pause();
        buildNotification(generateAction(android.R.drawable.ic_media_play, "Play", ACTION_PLAY));
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void play(MediaPlayer player) {
        player.start();
        buildNotification(generateAction(android.R.drawable.ic_media_pause, "Pause", ACTION_PAUSE));
    }

    private void stop() {
        NotificationManager notificationManager = (NotificationManager) getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
        notificationManager.cancel( 1 );
        Intent intent = new Intent( getApplicationContext(), AudioService.class );
        stopService( intent );
    }


    @Override
    public void onDestroy() {
        super.onDestroy();
        if (mMediaPlayer != null) mMediaPlayer.release();
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    private void createNotificationChannel() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            NotificationChannel serviceChannel = new NotificationChannel(
                    CHANNEL_ID,
                    "Foreground Service Channel",
                    NotificationManager.IMPORTANCE_DEFAULT
            );

            NotificationManager manager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
            manager.createNotificationChannel(serviceChannel);
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    @Override
    public void onPrepared(MediaPlayer player) {
        play(player);
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT_WATCH)
    private Notification.Action generateAction(int icon, String title, String intentAction) {
        Intent intent = new Intent(getApplicationContext(), AudioService.class);
        intent.setAction(intentAction);
        PendingIntent pendingIntent = PendingIntent.getService(getApplicationContext(), 1, intent, 0);
        return new Notification.Action.Builder(icon, title, pendingIntent).build();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void buildNotification(Notification.Action action) {
        createNotificationChannel();

        Notification.MediaStyle style = new Notification.MediaStyle();

        Intent notificationIntent = new Intent(this, AudioPlayerChopinzinhofmPlugin.class);
        PendingIntent pendingIntent = PendingIntent.getActivity(this,
                0, notificationIntent, 0);

        Notification.Builder builder = new Notification.Builder(this, CHANNEL_ID)
                .setContentTitle("ChopinzinhoFM 102,9")
                .setContentText("Você está ouvindo a nossa FM")
                .setDeleteIntent(pendingIntent)
                .setStyle(style);
        builder.addAction(generateAction(R.drawable.ic_stop, "Stop", ACTION_STOP));
        builder.addAction(action);
        style.setShowActionsInCompactView(0, 1);

        startForeground(1, builder.build());
    }

    @Override
    public boolean onError(MediaPlayer mediaPlayer, int i, int i1) {
        System.out.println("errrorr");
        return false;
    }

}

==> audio_player_chopinzinhofm-0.0.3.tar.gz: android/src/main/java/audioplayerchopinzinhofm/lucas/com/audio_player_chopinzinhofm/AudioService.java <==
package audioplayerchopinzinhofm.lucas.com.audio_player_chopinzinhofm;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.media.Rating;
import android.media.session.MediaController;
import android.media.session.MediaSession;
import android.media.session.MediaSessionManager;
import android.os.Build;
import android.os.IBinder;
import android.os.PowerManager;
import android.support.annotation.Nullable;
import android.support.annotation.RequiresApi;
import android.util.Log;

import java.io.IOException;

public class AudioService extends Service implements MediaPlayer.OnPreparedListener, MediaPlayer.OnErrorListener {

    public static final String CHANNEL_ID = "ForegroundServiceChannel";
    public static final String ACTION_PLAY = "action_play";
    public static final String ACTION_PAUSE = "action_pause";
    public static final String ACTION_STOP = "action_stop";
    private static final String URL = "http://9.fm5.com.br:8804/;";


    private MediaPlayer mMediaPlayer;

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        createNotificationChannel();

        if (intent.getAction().equals(ACTION_PLAY)) {
            if (mMediaPlayer == null) {
                startMediaPlayer();
            } else {
                play(mMediaPlayer);
            }
        } else if (intent.getAction().equals(ACTION_PAUSE)) {
            pause(mMediaPlayer);
        } else if (intent.getAction().equals(ACTION_STOP)) {
            stop();
        }

        return START_NOT_STICKY;
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void startMediaPlayer() {
        mMediaPlayer = new MediaPlayer();
        mMediaPlayer.setAudioStreamType(AudioManager.STREAM_MUSIC);
        mMediaPlayer.setWakeMode(getApplicationContext(), PowerManager.PARTIAL_WAKE_LOCK);
        try {
            mMediaPlayer.setDataSource(URL);
        } catch (IOException e) {
            e.printStackTrace();
        }
        mMediaPlayer.setOnPreparedListener(this);
        mMediaPlayer.setOnErrorListener(this);
        mMediaPlayer.prepareAsync();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void pause(MediaPlayer player) {
        player.pause();
        buildNotification(generateAction(android.R.drawable.ic_media_play, "Play", ACTION_PLAY));
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void play(MediaPlayer player) {
        player.start();
        buildNotification(generateAction(android.R.drawable.ic_media_pause, "Pause", ACTION_PAUSE));
    }

    private void stop() {
        NotificationManager notificationManager = (NotificationManager) getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
        notificationManager.cancel( 1 );
        Intent intent = new Intent( getApplicationContext(), AudioService.class );
        stopService( intent );
    }


    @Override
    public void onDestroy() {
        super.onDestroy();
        if (mMediaPlayer != null) mMediaPlayer.release();
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    private void createNotificationChannel() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            NotificationChannel serviceChannel = new NotificationChannel(
                    CHANNEL_ID,
                    "Foreground Service Channel",
                    NotificationManager.IMPORTANCE_DEFAULT
            );

            NotificationManager manager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
            manager.createNotificationChannel(serviceChannel);
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    @Override
    public void onPrepared(MediaPlayer player) {
        play(player);
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT_WATCH)
    private Notification.Action generateAction(int icon, String title, String intentAction) {
        Intent intent = new Intent(getApplicationContext(), AudioService.class);
        intent.setAction(intentAction);
        PendingIntent pendingIntent = PendingIntent.getService(getApplicationContext(), 1, intent, 0);
        return new Notification.Action.Builder(icon, title, pendingIntent).build();
    }

    @RequiresApi(api = Build.VERSION_CODES.O)
    private void buildNotification(Notification.Action action) {
        createNotificationChannel();

        Notification.MediaStyle style = new Notification.MediaStyle();

        Intent notificationIntent = new Intent(this, AudioPlayerChopinzinhofmPlugin.class);
        PendingIntent pendingIntent = PendingIntent.getActivity(this,
                0, notificationIntent, 0);

        Notification.Builder builder = new Notification.Builder(this, CHANNEL_ID)
                .setContentTitle("ChopinzinhoFM 102,9")
                .setContentText("Você está ouvindo a nossa FM")
                .setDeleteIntent(pendingIntent)
                .setStyle(style);
        builder.addAction(generateAction(android.R.drawable.ic_delete, "Stop", ACTION_STOP));
        builder.addAction(action);
        style.setShowActionsInCompactView(0, 1);

        startForeground(1, builder.build());
    }

    @Override
    public boolean onError(MediaPlayer mediaPlayer, int i, int i1) {
        System.out.println("errrorr");
        return false;
    }

}
